@@ -1,4 +1,3 @@
-from dataclasses import dataclass
 import math
 from typing import (
     Optional, 
@@ -37,9 +36,16 @@ class Player:
     ):
         self._id: int = id
 
+        _players.append(self)
+
     # use id as hash
     def __hash__(self) -> int:
-        return self._id
+        return hash(self._id)
+
+    def __eq__(self, value: object) -> bool:
+        if isinstance(value, Player):
+            return self._id == value._id
+        return False
 
     @property
     def id(self) -> int:
@@ -487,7 +493,6 @@ class Player:
 
         funcs.send_client_message(self._id, color.to_alpha(), message)
 
-
     def send_announce(self, type: int, message: str):
         """
         Send announce message to the player
@@ -528,7 +533,6 @@ class Player:
         """
         funcs.play_sound(self.unique_world, sound_id, x, y, z)
         
-
     def set_vehicle_slot(self, vehicle: 'Vehicle', slot: int):
         """
         Set the player vehicle slot
@@ -699,6 +703,14 @@ class Vehicle:
     def __init__(self, vehicle_id: int):
         self._id = vehicle_id
 
+    def __hash__(self) -> int:
+        return hash(self._id)
+
+    def __eq__(self, value: object) -> bool:
+        if isinstance(value, Vehicle):
+            return self._id == value._id
+        return False
+
     @property
     def id(self):
         return self._id
@@ -1376,6 +1388,14 @@ class Pickup:
     def __init__(self, pickup_id: int):
         self._id = pickup_id
 
+    def __hash__(self) -> int:
+        return hash(self._id)
+
+    def __eq__(self, value: object) -> bool:
+        if isinstance(value, Pickup):
+            return self._id == value._id
+        return False
+
     @property
     def id(self) -> int:
         return self._id
@@ -1497,6 +1517,14 @@ class CheckPoint:
     def __init__(self, id: int):
         self._id = id
 
+    def __hash__(self) -> int:
+        return hash(self._id)
+
+    def __eq__(self, value: object) -> bool:
+        if isinstance(value, CheckPoint):
+            return self._id == value._id
+        return False
+
     @property
     def id(self) -> int:
         return self._id
@@ -1588,6 +1616,14 @@ class Object:
     def __init__(self, id: int):
         self._id = id
 
+    def __hash__(self) -> int:
+        return hash(self._id)
+
+    def __eq__(self, value: object) -> bool:
+        if isinstance(value, Object):
+            return self._id == value._id
+        return False
+
     @property
     def id(self) -> int:
         return self._id
@@ -1717,6 +1753,14 @@ class Marker:
     def __init__(self, id: int):
         self._id = id
 
+    def __hash__(self) -> int:
+        return hash(self._id)
+
+    def __eq__(self, value: object) -> bool:
+        if isinstance(value, Marker):
+            return self._id == value._id
+        return False
+
     @property
     def id(self) -> int:
         return self._id
